@@ -89,9 +89,6 @@ def combine_args_config(sken_config):
     if parsed_args.scanner is not None:
         sken_config['scanner'] = parsed_args.scanner
 
-    if parsed_args.secrets is not None:
-        sken_config['secrets'] = parsed_args.secrets
-
     if parsed_args.lang is not None:
         sken_config['language'] = parsed_args.lang
     
@@ -315,6 +312,9 @@ def trigger_etl(timestamp, fileName, scanner, output_empty):
     except Exception as e:
         print('Failed to trigger ETL: ' + str(e))
 
+def version():
+    return '0.1.43'
+
 def main():
     parser = argparse.ArgumentParser(description='Sken Runner.')
     parser.add_argument('-s', '--scanner', metavar='scanner', choices=SCANNERS, help='support scanners: ' + ','.join(SCANNERS))
@@ -325,8 +325,14 @@ def main():
 
     parser.add_argument('--api_id', metavar='API Id', help='API Id.')
     parser.add_argument('--app_id', metavar='Application Id', help='Application Id.')
+    parser.add_argument('--version', metavar='Version', nargs='?', default='', help='Version.')
+
     global parsed_args
     parsed_args = parser.parse_args()
+
+    if 'version' in parsed_args:
+        print('Skencli: ' + version())
+        exit(0)
     
     precheck()
     get_scan_info()
